@@ -437,8 +437,17 @@ read_config(AppletConfig *config){
 	g_free(tmp);
     }
 
+	/* Get value of switch  UI background. Default is FALSE. */
+	value = NULL;
+	value = gconf_client_get(gconf_client, GCONF_KEY_UI_BACKGROUND_COLOR_ON, NULL);
+	if(value){
+		config->ui_background_color_on = TRUE;
+    	gconf_value_free(value);
+	}
+	else
+    	config->ui_background_color_on = FALSE;
+
     /* Get UI background color */
-    config->ui_background_color_on = TRUE;
     config->ui_background_color.red = 0xCCCC;
     config->ui_background_color.blue = 0xCCCC;
     config->ui_background_color.green = 0xCCCC;
@@ -787,6 +796,10 @@ config_save(AppletConfig *config){
     gconf_client_set_string(gconf_client,
         		    GCONF_KEY_WEATHER_FONT,
 			    config->font, NULL);
+     /* Save UI Background color state */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_UI_BACKGROUND_COLOR_ON,
+			    config->ui_background_color_on, NULL);
     /* Save Background Color */
     sprintf(temp_buffer, "#%02x%02x%02x",
             config->background_color.red >> 8,
@@ -829,7 +842,7 @@ config_save(AppletConfig *config){
      /* Save Swap Temperature Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SWAP_TEMPERATURE,
-			config->swap_hi_low_temperature, NULL);	    
+			config->swap_hi_low_temperature, NULL);
      /* Save Show Wind Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SHOW_WIND,
