@@ -26,14 +26,19 @@
  *	
 */
 /*******************************************************************************/
+#include "weather-common.h"
 #include "weather-data.h"
 #include <stdio.h>
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
-WeatherComStation wcs = { NULL };
-/*******************************************************************************/
-Item* create_item(const char *name, const char *value){
-    Item	*itm = NULL;
-
+Item*
+create_item(const char *name, const char *value){
+    Item	*itm=NULL;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(!name)
 	return NULL;
     
@@ -44,29 +49,39 @@ Item* create_item(const char *name, const char *value){
     return itm;
 }
 /*******************************************************************************/
-void destroy_item(Item **item){
+void
+destroy_item(Item **item){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(!(*item))
 	return;
     if((*item)->name)
 	g_string_free((*item)->name, TRUE);
     if((*item)->value)
 	g_string_free((*item)->value, TRUE);
-
     g_free(*item);
     *item = NULL;
 }
 /*******************************************************************************/
-GSList*	add_item2object(GSList **object, Item *item){
+GSList*
+add_item2object(GSList **object, void *item){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(item)
 	*object = g_slist_append(*object, item);
     return (*object);
 }
 /*******************************************************************************/
-char* item_value(GSList *object, const char *name){
+char*
+item_value(GSList *object, const char *name){
     GString	*tmp = NULL;
     Item	*itm = NULL;
     char	*result = "";
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(object){
         tmp = g_string_new(name);
 	while(object){
@@ -82,39 +97,8 @@ char* item_value(GSList *object, const char *name){
     return result;
 }
 /*******************************************************************************/
-void destroy_object(GSList **object){
-    Item	*itm = NULL;
-    GSList	*tmp = *object;
-
-    while(tmp){
-	itm = (Item*)tmp->data;
-	if(itm)
-	    destroy_item(&itm);
-	tmp = g_slist_next(tmp);
-    }
-    g_slist_free(*object);
-    *object = NULL;
-}
-/*******************************************************************************/
-time_t last_update_time(GSList *object){
-    time_t	last_update = 0;
-    struct tm	tm = {0};
-
-    if(!object)
-	return 0;
-
-    strptime(item_value(object, "last_update"), "%D %I:%M", &tm);
-    tm.tm_isdst = 1;
-    last_update = mktime(&tm);
-
-    /* Add 12 hours if  date have PM field */
-    if(strstr(item_value(object, "last_update"), "PM"))
-	last_update += 12 * 3600;
-
-//    last_update -= 3600; /* TODO. I don't understand why this is needed. */
-    return last_update;
-}
-time_t calculate_diff_time(int timezone){
+time_t
+calculate_diff_time(int timezone){
 
     time_t	current_time,
                 diff_time = 0,
@@ -127,14 +111,57 @@ time_t calculate_diff_time(int timezone){
     gmt->tm_isdst = 1;
     /* correct time for current location */
     utc_time = mktime(gmt);
+
     diff_time = utc_time - current_time  + 60 * 60 * timezone;
 
     return diff_time;
 }
 /*******************************************************************************/
-#ifndef RELEASE
-void display_all_object_items(GSList *object){
+void
+destroy_object(GSList **object){
     Item	*itm = NULL;
+    GSList	*tmp = *object;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    while(tmp){
+	itm = (Item*)tmp->data;
+	if(itm)
+	    destroy_item(&itm);
+	tmp = g_slist_next(tmp);
+    }
+    g_slist_free(*object);
+    *object = NULL;
+}
+/*******************************************************************************/
+time_t
+last_update_time(GSList *object){
+    time_t	last_update = 0;
+    struct tm	tm = {0};
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if(!object)
+	return 0;
+
+    strptime(item_value(object, "last_update"), "%D %I:%M", &tm);
+    tm.tm_isdst = 1;
+    last_update = mktime(&tm);
+
+    /* Add 12 hours if  date have PM field */
+    if(strstr(item_value(object, "last_update"), "PM"))
+	last_update += 12 * 3600;
+
+    return last_update;
+}
+/*******************************************************************************/
+#ifndef RELEASE
+void
+display_all_object_items(GSList *object){
+    Item	*itm = NULL;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     fprintf(stderr, "\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
     while(object){
 	itm = (Item*)object->data;
