@@ -32,6 +32,9 @@
 #define USER_DATA_MAGIC 0xaadcaadc
 #endif
 #define GCONF_KEY_CURRENT_CONNECTIVITY	"/system/osso/connectivity/IAP/current"
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
 static GString *url = NULL;
 static gboolean second_attempt = FALSE;
@@ -47,6 +50,9 @@ static     gchar	*station_name = NULL,
 /*******************************************************************************/
 /* Create standard Hildon animation small window */
 static void create_window_update(void){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     update_window = hildon_banner_show_animation(app->main_window,
 						    NULL,
 						    _("Update weather"));
@@ -58,9 +64,8 @@ get_connection_status_signal_cb(DBusConnection *connection,
         DBusMessage *message, void *user_data){
 
     gchar *iap_name = NULL, *iap_nw_type = NULL, *iap_state = NULL;
-    
-#ifndef RELEASE
-    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
 #endif
     /* check signal */
     if(!dbus_message_is_signal(message,
@@ -106,7 +111,6 @@ get_connection_status_signal_cb(DBusConnection *connection,
 #endif
 /*******************************************************************************/
 /* Callback function for request  connection to Internet */
-
 #ifdef USE_CONIC
 #define OSSO_CON_IC_CONNECTING             0x05
 static void connection_cb(ConIcConnection *connection,
@@ -116,8 +120,8 @@ static void connection_cb(ConIcConnection *connection,
     const gchar *iap_id, *bearer;
     ConIcConnectionStatus status;
     ConIcConnectionError error;
-#ifndef RELEASE
-    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
 #endif
     status = con_ic_connection_event_get_status(event);
     error = con_ic_connection_event_get_error(event);
@@ -126,9 +130,9 @@ static void connection_cb(ConIcConnection *connection,
 
     switch (status) {
         case CON_IC_STATUS_CONNECTED:
-#ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
 	    second_attempt = TRUE;
-	    update_weather();
+	    update_weather(FALSE);
 #endif
             app->iap_connecting = FALSE;
     	    app->iap_connected = TRUE;
@@ -157,15 +161,15 @@ static void connection_cb(ConIcConnection *connection,
 #else
 
 void iap_callback(struct iap_event_t *event, void *arg){
-#ifndef RELEASE
-    fprintf(stderr,"%s() %i\n", __PRETTY_FUNCTION__,event->type);
-#endif    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     app->iap_connecting = FALSE;
     switch(event->type){
 	case OSSO_IAP_CONNECTED:
-#ifndef RELEASE
+#ifdef DEBUGFUNCTIONCALL
 	    second_attempt = TRUE;
-	    update_weather();
+	    update_weather(FALSE);
 #endif
     	    app->iap_connected = TRUE;
 	break;
@@ -185,21 +189,21 @@ void iap_callback(struct iap_event_t *event, void *arg){
 /*******************************************************************************/
 void weather_initialize_dbus(void){
 
-    gchar		*filter_string,
-			*tmp;
-    GConfClient		*gconf_client = NULL;
+    gchar		*tmp;		
+#ifdef USE_DBUS
+    gchar		*filter_string;
     DBusConnection	*dbus_conn;
-
-#ifndef RELEASE
-    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
 #endif
-
+    GConfClient		*gconf_client = NULL;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
     if(!app->dbus_is_initialize){   
 	/* Reseting values */
         app->iap_connecting = FALSE;
 	app->iap_connected = FALSE;
 	app->iap_connecting_timer = 0;
-
+	
 	/* Check connection */
 	gconf_client = gconf_client_get_default();
 	if(gconf_client){
@@ -250,6 +254,9 @@ void weather_initialize_dbus(void){
 /*******************************************************************************/
 /* Init easy curl */
 CURL* weather_curl_init(CURL *curl_handle){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     curl_handle = curl_easy_init(); 
     curl_easy_setopt(curl_handle, CURLOPT_NOPROGRESS, 1); 
     curl_easy_setopt(curl_handle, CURLOPT_FOLLOWLOCATION, 1); 
@@ -272,7 +279,9 @@ CURL* weather_curl_init(CURL *curl_handle){
 static int data_read(void *buffer, size_t size, size_t nmemb, void *stream){
     int result;
     struct HtmlFile *out = (struct HtmlFile *)stream;
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(out && !out->stream){
     /* open file for writing */
 	out->stream = fopen(out->filename, "wb");
@@ -288,7 +297,9 @@ static int data_read(void *buffer, size_t size, size_t nmemb, void *stream){
    Else return FLASE. This the end list
 */
 static gboolean form_url_and_filename(gchar *station_code){
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(station_code == NULL)
 	return FALSE;
     if(url){
@@ -300,8 +311,9 @@ static gboolean form_url_and_filename(gchar *station_code){
         full_filename_new_xml = NULL;
     } 
     url = g_string_new(NULL);        
-    g_string_append_printf(url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&link=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=%d",
-				    station_code, Max_count_weather_day);
+    g_string_append_printf(url,
+			    weather_sources[app->config->weather_source].url,
+			    station_code);
     full_filename_new_xml = g_string_new(NULL);        
     g_string_append_printf(full_filename_new_xml,"%s/%s.xml.new",
 				    app->config->cache_dir_name,station_code);
@@ -319,11 +331,12 @@ gboolean download_html(gpointer data){
     int		max;
     gint	num_transfers = 0,
 		num_msgs = 0;		
-#ifndef RELEASE
-    fprintf(stderr,"%s()\n", __PRETTY_FUNCTION__);
-#endif    
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(app->popup_window && app->show_update_window){
-        popup_window_destroy();
+	gtk_widget_destroy(app->popup_window);
+	app->popup_window = NULL;
     }
     /* If not connected and it autoupdate do go away */
     if(!app->show_update_window && !app->iap_connected){
@@ -352,7 +365,7 @@ gboolean download_html(gpointer data){
         return TRUE;
     }
 
-    if (app->iap_connecting){
+    if(app->iap_connecting){
 	/* Check buggy */
 	if (app->iap_connecting_timer > 150){
 	    if(app->show_update_window){
@@ -472,7 +485,7 @@ gboolean download_html(gpointer data){
 			    hildon_banner_show_information(app->main_window,
 							    NULL,
 							    _("Weather updated"));
-        		weather_frame_update(FALSE);	
+        		redraw_home_window(FALSE);	
 		    }
 		    else{
 			valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list),
@@ -537,6 +550,9 @@ gboolean download_html(gpointer data){
 }
 /*******************************************************************************/
 void clean_download(void){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(curl_multi)
 	curl_multi_cleanup(curl_multi);
     curl_multi = NULL;
@@ -547,10 +563,14 @@ void clean_download(void){
     }
 }
 /*******************************************************************************/
+/*
 void pre_update_weather(void){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if (!app->dbus_is_initialize)
 	weather_initialize_dbus();
-    app->show_update_window = TRUE;
-    update_weather();
+    update_weather(TRUE);
 }
+*/
 /*******************************************************************************/
