@@ -191,6 +191,26 @@ GtkWidget* create_time_updates_widget(GSList *current){
     return main_widget;
 }
 /*******************************************************************************/
+gboolean make_current_tab(GtkWidget *vbox)
+{
+	GtkWidget *child = create_current_tab(app->wsd.current);
+	gtk_container_add(GTK_CONTAINER(vbox),child);
+	gtk_widget_show_all(vbox);
+	return FALSE;
+}
+/*******************************************************************************/
+gboolean make_tab(GtkWidget *vbox)
+{
+        GSList	*day = NULL;
+        gchar	*day_name = NULL;
+	GtkWidget *child;
+	day = (GSList*)g_object_get_data(G_OBJECT(vbox), "day");
+	child = create_day_tab(app->wsd.current, day, &day_name);
+	gtk_container_add(GTK_CONTAINER(vbox),child);
+	gtk_widget_show_all(vbox);
+	return FALSE;
+}
+/*******************************************************************************/
 gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
                     	    				    gpointer user_data){
     GtkWidget	*window_popup = NULL,
@@ -204,9 +224,10 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 		*refresh_button = NULL,
 		*about_button = NULL,
 		*close_button = NULL;
-    gint	active_tab = 0,
+        gint	active_tab = 0,
 		k = 0,
-		i = 0;
+		page = 0,
+		i = 1;
     gchar	*day_name = NULL;
     time_t      current_time = 0,
                 diff_time,
@@ -227,7 +248,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 /* Main window */
     window_popup = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     
-    if (app->config->ui_background_color_on)
+    if(app->config->ui_background_color_on)
 	set_background_color(window_popup, &(app->config->ui_background_color));
 
     g_object_set_data(G_OBJECT(window_popup), "active_tab", (gpointer)active_tab);
@@ -237,9 +258,8 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
     gtk_container_add(GTK_CONTAINER(window_popup), vbox);
 /* station name */
     gtk_box_pack_start(GTK_BOX(vbox),
-    			label = gtk_label_new(app->config->current_station_name),
+			create_window_header(app->config->current_station_name, window_popup),
 			FALSE, TRUE, 20);
-    set_font(label, NULL, 28);
 /* create tabs widget */
     notebook = gtk_notebook_new();
     if (app->config->ui_background_color_on){
@@ -275,23 +295,46 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 		( current_time - app->config->data_valid_interval)) &&
 	    (current_data_last_update <
 		( current_time + app->config->data_valid_interval)))
-	current_tab = create_current_tab(app->wsd.current);
+	current_tab = gtk_vbox_new(FALSE, 0);
 
-    if(current_tab)
-	gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+    if(current_tab){
+      if(active_tab == 0 && app->config->separate){
+        gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
 				current_tab,
 				gtk_label_new(_("Now")));
+	    make_current_tab(current_tab); 
+	  }else{
+	    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+				current_tab,
+				gtk_label_new(_("Now")));
+	    g_idle_add((GSourceFunc)make_current_tab,current_tab);
+	  }
+    }
 /* if weather is separated than hide one day */
     (app->config->separate) ? (k = 1) : (k = 0);
 /* Day tabs */
     tmp = app->wsd.days;
     while(tmp && i < app->config->days_to_show){
 	day = (GSList*)tmp->data;
-	tab = create_day_tab(app->wsd.current, day, &day_name);
-	if(tab){
-	    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+	/* Acceleration of starting gtk_notebook */
+	if (active_tab != i){
+	    /* Create the empty page */
+	    tab = create_pseudo_day_tab(app->wsd.current, day, &day_name);
+	    if(tab){
+	    	page = gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         				tab,
         				gtk_label_new(day_name));
+		g_object_set_data(G_OBJECT(tab), "day", (gpointer)tmp->data);
+		g_idle_add((GSourceFunc)make_tab,tab);
+	    }
+	}else{	
+	    /* Create the page with data */
+	    tab = create_day_tab(app->wsd.current, day, &day_name);
+	    if(tab){
+		page = gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        				tab,
+        				gtk_label_new(day_name));
+	    }
 	}
 	day_name && (g_free(day_name), day_name = NULL);
 	tmp = g_slist_next(tmp);
@@ -328,7 +371,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 			(gpointer)window_popup);
 
 /* Change background color on buttons */
-    if (app->config->ui_background_color_on){
+    if(app->config->ui_background_color_on){
 	set_background_color(close_button, &(app->config->ui_background_color));
 	set_background_color(settings_button, &(app->config->ui_background_color));
 	set_background_color(refresh_button, &(app->config->ui_background_color));	
@@ -366,6 +409,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 	    else
 		if(current_tab && active_tab)
 		    active_tab++;
+		    
 	    gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), active_tab);
 	}
     }
@@ -441,6 +485,22 @@ void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
     gtk_widget_destroy(GTK_WIDGET(user_data));
 }
 /*******************************************************************************/
+GtkWidget* create_pseudo_day_tab(GSList *current, GSList *day, gchar **day_name){
+    GtkWidget	*main_widget = NULL;
+    gchar	buffer[1024];
+    struct tm	tmp_time_date_struct = {0};
+
+    main_widget = gtk_vbox_new(FALSE, 0);
+    /* prepare localized day name */
+    memset(buffer, 0, sizeof(buffer));
+    sprintf(buffer,"%s", item_value(day, "24h_name"));
+    strptime(buffer, "%a", &tmp_time_date_struct);
+    *day_name = g_strdup(buffer);
+
+    return main_widget;
+}
+/*******************************************************************************/
+
 GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name){
     const gint	font_size = 14;
     GtkWidget	*main_widget = NULL,
@@ -841,3 +901,41 @@ GtkWidget* create_copyright_widget(const gchar *text, const gchar *image){
     return main_widget;
 }
 /*******************************************************************************/
+GtkWidget* create_window_header(const gchar *station_name, GtkWidget *popup_window){
+    GtkWidget	*main_widget = NULL,
+		*label = NULL,
+		*previos_button = NULL,
+		*next_button = NULL;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    main_widget = gtk_hbox_new(FALSE, 0);
+/* station name */
+    label = gtk_label_new(station_name);
+    set_font(label, NULL, 28);
+/* previos button */
+    previos_button = create_button_with_image(NULL, "qgn_list_hw_button_left",
+                    				26, FALSE, FALSE);
+/* next button */
+    next_button = create_button_with_image(NULL, "qgn_list_hw_button_right",
+                    				26, FALSE, FALSE);
+    if(previos_button){
+	gtk_box_pack_start(GTK_BOX(main_widget), previos_button, FALSE, FALSE, 10);
+	g_signal_connect(G_OBJECT(previos_button), "button_press_event",
+                	G_CALLBACK(change_station_prev), popup_window);
+    }
+    if(label)
+	gtk_box_pack_start(GTK_BOX(main_widget), label, TRUE, TRUE, 0);
+    if(next_button){
+	gtk_box_pack_start(GTK_BOX(main_widget), next_button, FALSE, FALSE, 10);
+	g_signal_connect(G_OBJECT(next_button), "button_press_event",
+                	G_CALLBACK(change_station_next), popup_window);
+    }
+
+    if(app->config->ui_background_color_on){
+	set_background_color(previos_button, &(app->config->ui_background_color));
+	set_background_color(next_button, &(app->config->ui_background_color));
+    }
+    return main_widget;
+}
+/*******************************************************************************/
