@@ -51,9 +51,10 @@ void weather_window_settings(GtkWidget *widget, GdkEvent *event,
 				gpointer user_data);
 void station_list_view_select_handler(GtkTreeView *tree_view,
 			    gpointer user_data);
+gboolean process_locations_tab(GtkWidget *vbox);
 gboolean changed_country_process(gpointer user_data);
 void changed_country_handler(GtkWidget *widget, gpointer user_data);
-gboolean changed_country_process(gpointer user_data);
+gboolean changed_state_process(gpointer user_data);
 void changed_state_handler(GtkWidget *widget, gpointer user_data);
 void changed_stations_handler(GtkWidget *widget, gpointer user_data);
 void changed_weather_source_handler(GtkWidget *widget, gpointer user_data);
